PlaceholderSyntaxError

Struct PlaceholderSyntaxError 

pub struct PlaceholderSyntaxError {
    pub message: String,
    pub position: usize,
    pub placeholder: Option<String>,
}
Detailed information about placeholder parsing failures.

Fields

message: String

Human‑readable reason for the failure.

position: usize

Zero-based byte offset in the original pattern where parsing failed.

placeholder: Option<String>

Name of the placeholder, when known.

Implementations

Source

impl PlaceholderSyntaxError

pub fn new( message: impl Into<String>, position: usize, placeholder: Option<String>, ) -> Self

Construct a new syntax error with optional placeholder context.

pub fn user_message(&self) -> String

Return the user‑facing message without the “invalid placeholder syntax” prefix.