pub enum StepExecution {
Continue {
value: Option<Box<dyn Any>>,
},
Skipped {
message: Option<String>,
},
}Expand description
Outcome produced by step wrappers.
Variants
Continue
The step executed successfully and may provide a value for later steps.
Skipped
The step requested that the scenario should be skipped.
Implementations